@@ -8,11 +8,13 @@ from signum.plotting.plotter import Plotter
 
 
 class PolarPlotter(Plotter):
-    def __init__(self, figsize=(6, 6), db_scale=False, **kwargs):
+    def __init__(self, figsize=(6, 6), db_scale=False, unit='', **kwargs):
         super().__init__(n_rows=1, n_cols=1, figsize=figsize, subplot_kw={'projection': 'polar'}, **kwargs)
 
         self._db_scale = db_scale
 
+        self.ax.set_y_unit(unit)
+
         self.ax.grid(color='lightgrey')
 
     @property
@@ -23,6 +25,6 @@ class PolarPlotter(Plotter):
         mag = signal.magnitude_db if self._db_scale else signal.magnitude
         phase = signal.get_phase(rad=True)
 
-        line, = self.ax.plot(phase.T, mag.T, **kwargs)
+        lines = self.ax.plot(phase.T, mag.T, **kwargs)
 
-        return line,
+        return lines
